@@ -13,7 +13,7 @@ case $TARGETPLATFORM in
     "linux/arm/v7")
         arch="armv7"
         ;;
-    "riscv64")
+    "linux/riscv64")
         arch="riscv64"
         ;;
     *)
@@ -22,4 +22,4 @@ case $TARGETPLATFORM in
         ;;        
 esac
 file_name="$os$arch-$(cat bin/version.txt)"
-echo $file_name
\ No newline at end of file
+echo $file_name
