@@ -2,12 +2,11 @@ package route
 
 import (
 	"github.com/metacubex/mihomo/constant"
-	"net/http"
-
 	"github.com/metacubex/mihomo/tunnel"
 
-	"github.com/go-chi/chi/v5"
-	"github.com/go-chi/render"
+	"github.com/metacubex/chi"
+	"github.com/metacubex/chi/render"
+	"github.com/metacubex/http"
 )
 
 func ruleRouter() http.Handler {
