@@ -3,8 +3,6 @@ package inner
 import (
 	"errors"
 	"net"
-	"net/netip"
-	"strconv"
 
 	N "github.com/metacubex/mihomo/common/net"
 	C "github.com/metacubex/mihomo/constant"
@@ -16,9 +14,13 @@ func New(t C.Tunnel) {
 	tunnel = t
 }
 
-func HandleTcp(address string, proxy string) (conn net.Conn, err error) {
+func GetTunnel() C.Tunnel {
+	return tunnel
+}
+
+func HandleTcp(tunnel C.Tunnel, address string, proxy string) (conn net.Conn, err error) {
 	if tunnel == nil {
-		return nil, errors.New("tcp uninitialized")
+		return nil, errors.New("tunnel uninitialized")
 	}
 	// executor Parsed
 	conn1, conn2 := N.Pipe()
@@ -31,15 +33,8 @@ func HandleTcp(address string, proxy string) (conn net.Conn, err error) {
 	if proxy != "" {
 		metadata.SpecialProxy = proxy
 	}
-	if h, port, err := net.SplitHostPort(address); err == nil {
-		if port, err := strconv.ParseUint(port, 10, 16); err == nil {
-			metadata.DstPort = uint16(port)
-		}
-		if ip, err := netip.ParseAddr(h); err == nil {
-			metadata.DstIP = ip
-		} else {
-			metadata.Host = h
-		}
+	if err = metadata.SetRemoteAddress(address); err != nil {
+		return nil, err
 	}
 
 	go tunnel.HandleTCPConn(conn2, metadata)
