@@ -6,15 +6,13 @@ package gun
 import (
 	"bufio"
 	"context"
-	"crypto/tls"
 	"encoding/binary"
 	"errors"
 	"fmt"
 	"io"
 	"net"
-	"net/http"
-	"net/http/httptrace"
 	"net/url"
+	"strings"
 	"sync"
 	"time"
 
@@ -24,7 +22,9 @@ import (
 	tlsC "github.com/metacubex/mihomo/component/tls"
 	C "github.com/metacubex/mihomo/constant"
 
-	"golang.org/x/net/http2"
+	"github.com/metacubex/http"
+	"github.com/metacubex/http/httptrace"
+	"github.com/metacubex/tls"
 )
 
 var (
@@ -260,35 +260,34 @@ func NewHTTP2Client(dialFn DialFn, tlsConfig *tls.Config, clientFingerprint stri
 		}
 
 		if clientFingerprint, ok := tlsC.GetFingerprint(clientFingerprint); ok {
-			tlsConfig := tlsC.UConfig(cfg)
-			err := echConfig.ClientHandle(ctx, tlsConfig)
-			if err != nil {
-				pconn.Close()
-				return nil, err
-			}
-
 			if realityConfig == nil {
+				tlsConfig := tlsC.UConfig(cfg)
+				err := echConfig.ClientHandleUTLS(ctx, tlsConfig)
+				if err != nil {
+					pconn.Close()
+					return nil, err
+				}
 				tlsConn := tlsC.UClient(pconn, tlsConfig, clientFingerprint)
 				if err := tlsConn.HandshakeContext(ctx); err != nil {
 					pconn.Close()
 					return nil, err
 				}
 				state := tlsConn.ConnectionState()
-				if p := state.NegotiatedProtocol; p != http2.NextProtoTLS {
+				if p := state.NegotiatedProtocol; p != http.Http2NextProtoTLS {
 					tlsConn.Close()
-					return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http2.NextProtoTLS)
+					return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http.Http2NextProtoTLS)
 				}
 				return tlsConn, nil
 			} else {
-				realityConn, err := tlsC.GetRealityConn(ctx, pconn, clientFingerprint, tlsConfig, realityConfig)
+				realityConn, err := tlsC.GetRealityConn(ctx, pconn, clientFingerprint, cfg.ServerName, realityConfig)
 				if err != nil {
 					pconn.Close()
 					return nil, err
 				}
 				//state := realityConn.(*utls.UConn).ConnectionState()
-				//if p := state.NegotiatedProtocol; p != http2.NextProtoTLS {
+				//if p := state.NegotiatedProtocol; p != http.Http2NextProtoTLS {
 				//	realityConn.Close()
-				//	return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http2.NextProtoTLS)
+				//	return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http.Http2NextProtoTLS)
 				//}
 				return realityConn, nil
 			}
@@ -297,25 +296,10 @@ func NewHTTP2Client(dialFn DialFn, tlsConfig *tls.Config, clientFingerprint stri
 			return nil, errors.New("REALITY is based on uTLS, please set a client-fingerprint")
 		}
 
-		if echConfig != nil {
-			tlsConfig := tlsC.UConfig(cfg)
-			err := echConfig.ClientHandle(ctx, tlsConfig)
-			if err != nil {
-				pconn.Close()
-				return nil, err
-			}
-
-			conn := tlsC.Client(pconn, tlsConfig)
-			if err := conn.HandshakeContext(ctx); err != nil {
-				pconn.Close()
-				return nil, err
-			}
-			state := conn.ConnectionState()
-			if p := state.NegotiatedProtocol; p != http2.NextProtoTLS {
-				conn.Close()
-				return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http2.NextProtoTLS)
-			}
-			return conn, nil
+		err = echConfig.ClientHandle(ctx, cfg)
+		if err != nil {
+			pconn.Close()
+			return nil, err
 		}
 
 		conn := tls.Client(pconn, cfg)
@@ -324,14 +308,14 @@ func NewHTTP2Client(dialFn DialFn, tlsConfig *tls.Config, clientFingerprint stri
 			return nil, err
 		}
 		state := conn.ConnectionState()
-		if p := state.NegotiatedProtocol; p != http2.NextProtoTLS {
+		if p := state.NegotiatedProtocol; p != http.Http2NextProtoTLS {
 			conn.Close()
-			return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http2.NextProtoTLS)
+			return nil, fmt.Errorf("http2: unexpected ALPN protocol %s, want %s", p, http.Http2NextProtoTLS)
 		}
 		return conn, nil
 	}
 
-	transport := &http2.Transport{
+	transport := &http.Http2Transport{
 		DialTLSContext:     dialFunc,
 		TLSClientConfig:    tlsConfig,
 		AllowHTTP:          false,
@@ -341,18 +325,26 @@ func NewHTTP2Client(dialFn DialFn, tlsConfig *tls.Config, clientFingerprint stri
 
 	ctx, cancel := context.WithCancel(context.Background())
 	wrap := &TransportWrap{
-		Transport: transport,
-		ctx:       ctx,
-		cancel:    cancel,
+		Http2Transport: transport,
+		ctx:            ctx,
+		cancel:         cancel,
 	}
 	return wrap
 }
 
+func ServiceNameToPath(serviceName string) string {
+	if strings.HasPrefix(serviceName, "/") { // custom paths
+		return serviceName
+	}
+	return "/" + serviceName + "/Tun"
+}
+
 func StreamGunWithTransport(transport *TransportWrap, cfg *Config) (net.Conn, error) {
 	serviceName := "GunService"
 	if cfg.ServiceName != "" {
 		serviceName = cfg.ServiceName
 	}
+	path := ServiceNameToPath(serviceName)
 
 	reader, writer := io.Pipe()
 	request := &http.Request{
@@ -361,9 +353,9 @@ func StreamGunWithTransport(transport *TransportWrap, cfg *Config) (net.Conn, er
 		URL: &url.URL{
 			Scheme: "https",
 			Host:   cfg.Host,
-			Path:   fmt.Sprintf("/%s/Tun", serviceName),
+			Path:   path,
 			// for unescape path
-			Opaque: fmt.Sprintf("//%s/%s/Tun", cfg.Host, serviceName),
+			Opaque: "//" + cfg.Host + path,
 		},
 		Proto:      "HTTP/2",
 		ProtoMajor: 2,
