@@ -15,17 +15,17 @@ import (
 	N "github.com/metacubex/mihomo/common/net"
 	"github.com/metacubex/mihomo/common/pool"
 	"github.com/metacubex/mihomo/common/xsync"
-	tlsC "github.com/metacubex/mihomo/component/tls"
 	C "github.com/metacubex/mihomo/constant"
 	"github.com/metacubex/mihomo/log"
 	"github.com/metacubex/mihomo/transport/tuic/common"
 
 	"github.com/metacubex/quic-go"
 	"github.com/metacubex/randv2"
+	"github.com/metacubex/tls"
 )
 
 type ClientOption struct {
-	TlsConfig             *tlsC.Config
+	TlsConfig             *tls.Config
 	QuicConfig            *quic.Config
 	Uuid                  [16]byte
 	Password              string
@@ -39,7 +39,8 @@ type ClientOption struct {
 
 type clientImpl struct {
 	*ClientOption
-	udp bool
+	dialFn common.DialFunc
+	udp    bool
 
 	quicConn  *quic.Conn
 	connMutex sync.Mutex
@@ -50,7 +51,6 @@ type clientImpl struct {
 	udpInputMap xsync.Map[uint16, net.Conn]
 
 	// only ready for PoolClient
-	dialerRef   C.Dialer
 	lastVisited atomic2.TypedValue[time.Time]
 }
 
@@ -58,10 +58,6 @@ func (t *clientImpl) OpenStreams() int64 {
 	return t.openStreams.Load()
 }
 
-func (t *clientImpl) DialerRef() C.Dialer {
-	return t.dialerRef
-}
-
 func (t *clientImpl) LastVisited() time.Time {
 	return t.lastVisited.Load()
 }
@@ -70,13 +66,13 @@ func (t *clientImpl) SetLastVisited(last time.Time) {
 	t.lastVisited.Store(last)
 }
 
-func (t *clientImpl) getQuicConn(ctx context.Context, dialer C.Dialer, dialFn common.DialFunc) (*quic.Conn, error) {
+func (t *clientImpl) getQuicConn(ctx context.Context) (*quic.Conn, error) {
 	t.connMutex.Lock()
 	defer t.connMutex.Unlock()
 	if t.quicConn != nil {
 		return t.quicConn, nil
 	}
-	transport, addr, err := dialFn(ctx, dialer)
+	transport, addr, err := t.dialFn(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -270,7 +266,7 @@ func (t *clientImpl) forceClose(quicConn *quic.Conn, err error) {
 	if quicConn != nil {
 		_ = quicConn.CloseWithError(ProtocolError, errStr)
 	}
-	udpInputMap := t.udpInputMap
+	udpInputMap := &t.udpInputMap
 	udpInputMap.Range(func(key uint16, value net.Conn) bool {
 		conn := value
 		_ = conn.Close()
@@ -286,8 +282,8 @@ func (t *clientImpl) Close() {
 	}
 }
 
-func (t *clientImpl) DialContextWithDialer(ctx context.Context, metadata *C.Metadata, dialer C.Dialer, dialFn common.DialFunc) (net.Conn, error) {
-	quicConn, err := t.getQuicConn(ctx, dialer, dialFn)
+func (t *clientImpl) DialContext(ctx context.Context, metadata *C.Metadata) (net.Conn, error) {
+	quicConn, err := t.getQuicConn(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -337,8 +333,8 @@ func (t *clientImpl) DialContextWithDialer(ctx context.Context, metadata *C.Meta
 	return stream, nil
 }
 
-func (t *clientImpl) ListenPacketWithDialer(ctx context.Context, metadata *C.Metadata, dialer C.Dialer, dialFn common.DialFunc) (net.PacketConn, error) {
-	quicConn, err := t.getQuicConn(ctx, dialer, dialFn)
+func (t *clientImpl) ListenPacket(ctx context.Context, metadata *C.Metadata) (net.PacketConn, error) {
+	quicConn, err := t.getQuicConn(ctx)
 	if err != nil {
 		return nil, err
 	}
@@ -381,16 +377,16 @@ type Client struct {
 	*clientImpl // use an independent pointer to let Finalizer can work no matter somewhere handle an influence in clientImpl inner
 }
 
-func (t *Client) DialContextWithDialer(ctx context.Context, metadata *C.Metadata, dialer C.Dialer, dialFn common.DialFunc) (net.Conn, error) {
-	conn, err := t.clientImpl.DialContextWithDialer(ctx, metadata, dialer, dialFn)
+func (t *Client) DialContext(ctx context.Context, metadata *C.Metadata) (net.Conn, error) {
+	conn, err := t.clientImpl.DialContext(ctx, metadata)
 	if err != nil {
 		return nil, err
 	}
 	return N.NewRefConn(conn, t), err
 }
 
-func (t *Client) ListenPacketWithDialer(ctx context.Context, metadata *C.Metadata, dialer C.Dialer, dialFn common.DialFunc) (net.PacketConn, error) {
-	pc, err := t.clientImpl.ListenPacketWithDialer(ctx, metadata, dialer, dialFn)
+func (t *Client) ListenPacket(ctx context.Context, metadata *C.Metadata) (net.PacketConn, error) {
+	pc, err := t.clientImpl.ListenPacket(ctx, metadata)
 	if err != nil {
 		return nil, err
 	}
@@ -401,11 +397,11 @@ func (t *Client) forceClose() {
 	t.clientImpl.forceClose(nil, common.ClientClosed)
 }
 
-func NewClient(clientOption *ClientOption, udp bool, dialerRef C.Dialer) *Client {
+func NewClient(clientOption *ClientOption, udp bool, dialFn common.DialFunc) *Client {
 	ci := &clientImpl{
 		ClientOption: clientOption,
+		dialFn:       dialFn,
 		udp:          udp,
-		dialerRef:    dialerRef,
 	}
 	c := &Client{ci}
 	runtime.SetFinalizer(c, closeClient)
